pub struct AsyncAuditWriter { /* private fields */ }Expand description
Asynchronous audit writer: writes audit logs via a background thread to avoid blocking the main thread.
Uses an std::sync::mpsc channel to send logs to a background thread that
handles storage. Call shutdown to wait for the background thread to exit
and return all written logs.
Implementations
Sourceimpl AsyncAuditWriter
impl AsyncAuditWriter